// This is an auto-generated header, please don't modify it.
#define DTKGUI_CLASS_DDciIcon
#define DTKGUI_CLASS_DDciIconImagePlayer
#define DTKGUI_CLASS_DDciIconPalette
#define DTKGUI_CLASS_DDciIconPlayer
#define DTKGUI_CLASS_DDesktopServices
#define DTKGUI_CLASS_DFileDrag
#define DTKGUI_CLASS_DFileDragClient
#define DTKGUI_CLASS_DFileDragServer
#define DTKGUI_CLASS_DFontManager
#define DTKGUI_CLASS_DForeignWindow
#define DTKGUI_CLASS_DGuiApplicationHelper
#define DTKGUI_CLASS_DIcon
#define DTKGUI_CLASS_DIconTheme
#define DTKGUI_CLASS_DImageHandler
#define DTKGUI_CLASS_DNativeSettings
#define DTKGUI_CLASS_DPalette
#define DTKGUI_CLASS_DPlatformHandle
#define DTKGUI_CLASS_DPlatformTheme
#define DTKGUI_CLASS_DRegionMonitor
#define DTKGUI_CLASS_DSvgRenderer
#define DTKGUI_CLASS_DTaskbarControl
#define DTKGUI_CLASS_DThumbnailProvider
#define DTKGUI_CLASS_DWindowGroupLeader
#define DTKGUI_CLASS_DWindowManagerHelper
